package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.UpsBatteryLifecycle;
import com.os.ems.info.service.IUpsBatteryLifecycleService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 行李系统UPS电池生命周期Controller
 * 
 * @author zch
 * @date 2025-06-03
 */
@RestController
@RequestMapping("/ems/info/upsBatteryLifecycle")
public class UpsBatteryLifecycleController extends BaseController
{
    @Autowired
    private IUpsBatteryLifecycleService upsBatteryLifecycleService;

    /**
     * 查询行李系统UPS电池生命周期列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:upsBatteryLifecycle:list')")
    @GetMapping("/list")
    public TableDataInfo list(UpsBatteryLifecycle upsBatteryLifecycle)
    {
        startPage();
        List<UpsBatteryLifecycle> list = upsBatteryLifecycleService.selectUpsBatteryLifecycleList(upsBatteryLifecycle);
        return getDataTable(list);
    }

    /**
     * 导出行李系统UPS电池生命周期列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:upsBatteryLifecycle:export')")
    @Log(title = "行李系统UPS电池生命周期", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UpsBatteryLifecycle upsBatteryLifecycle)
    {
        List<UpsBatteryLifecycle> list = upsBatteryLifecycleService.selectUpsBatteryLifecycleList(upsBatteryLifecycle);
        ExcelUtil<UpsBatteryLifecycle> util = new ExcelUtil<UpsBatteryLifecycle>(UpsBatteryLifecycle.class);
        util.exportExcel(response, list, "行李系统UPS电池生命周期数据");
    }

    /**
     * 获取行李系统UPS电池生命周期详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:upsBatteryLifecycle:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(upsBatteryLifecycleService.selectUpsBatteryLifecycleById(id));
    }

    /**
     * 新增行李系统UPS电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:upsBatteryLifecycle:add')")
    @Log(title = "行李系统UPS电池生命周期", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UpsBatteryLifecycle upsBatteryLifecycle)
    {
        upsBatteryLifecycle.setCreateBy(getUsername());
        return toAjax(upsBatteryLifecycleService.insertUpsBatteryLifecycle(upsBatteryLifecycle));
    }

    /**
     * 修改行李系统UPS电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:upsBatteryLifecycle:edit')")
    @Log(title = "行李系统UPS电池生命周期", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UpsBatteryLifecycle upsBatteryLifecycle)
    {
        upsBatteryLifecycle.setUpdateBy(getUsername());
        return toAjax(upsBatteryLifecycleService.updateUpsBatteryLifecycle(upsBatteryLifecycle));
    }

    /**
     * 删除行李系统UPS电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:upsBatteryLifecycle:remove')")
    @Log(title = "行李系统UPS电池生命周期", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(upsBatteryLifecycleService.deleteUpsBatteryLifecycleByIds(ids));
    }
}
