package com.os.ems.info.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.ems.info.mapper.FaultHandlingRecordMapper;
import com.os.ems.info.domain.FaultHandlingRecord;
import com.os.ems.info.service.IFaultHandlingRecordService;

/**
 * 故障处置记录Service业务层处理
 * 
 * @author zch
 * @date 2025-06-03
 */
@Service
public class FaultHandlingRecordServiceImpl implements IFaultHandlingRecordService 
{
    @Autowired
    private FaultHandlingRecordMapper faultHandlingRecordMapper;

    /**
     * 查询故障处置记录
     * 
     * @param id 故障处置记录主键
     * @return 故障处置记录
     */
    @Override
    public FaultHandlingRecord selectFaultHandlingRecordById(Long id)
    {
        return faultHandlingRecordMapper.selectFaultHandlingRecordById(id);
    }

    /**
     * 查询故障处置记录列表
     * 
     * @param faultHandlingRecord 故障处置记录
     * @return 故障处置记录
     */
    @Override
    public List<FaultHandlingRecord> selectFaultHandlingRecordList(FaultHandlingRecord faultHandlingRecord)
    {
        return faultHandlingRecordMapper.selectFaultHandlingRecordList(faultHandlingRecord);
    }

    /**
     * 新增故障处置记录
     * 
     * @param faultHandlingRecord 故障处置记录
     * @return 结果
     */
    @Override
    public int insertFaultHandlingRecord(FaultHandlingRecord faultHandlingRecord)
    {
        return faultHandlingRecordMapper.insertFaultHandlingRecord(faultHandlingRecord);
    }

    /**
     * 修改故障处置记录
     * 
     * @param faultHandlingRecord 故障处置记录
     * @return 结果
     */
    @Override
    public int updateFaultHandlingRecord(FaultHandlingRecord faultHandlingRecord)
    {
        return faultHandlingRecordMapper.updateFaultHandlingRecord(faultHandlingRecord);
    }

    /**
     * 批量删除故障处置记录
     * 
     * @param ids 需要删除的故障处置记录主键
     * @return 结果
     */
    @Override
    public int deleteFaultHandlingRecordByIds(Long[] ids)
    {
        return faultHandlingRecordMapper.deleteFaultHandlingRecordByIds(ids);
    }

    /**
     * 删除故障处置记录信息
     * 
     * @param id 故障处置记录主键
     * @return 结果
     */
    @Override
    public int deleteFaultHandlingRecordById(Long id)
    {
        return faultHandlingRecordMapper.deleteFaultHandlingRecordById(id);
    }
}
